\name{olsfit}

\alias{olsfit}
\alias{loss.olsvario}
%- Also NEED an `\alias' for EACH other topic documented here.

\title{Variogram Fitting Using Ordinary Least Squares}

\description{
 Fits a covariance model to a empirical variogram. The parameters are
 estimated using weighted least squares.

}

\usage{
olsfit(vario, ini,
       cov.model = c("exponential", "matern", "gaussian",
                     "spherical", "circular", "cubic", "wave",
                     "powered.exponential", "cauchy", "gneiting",
                     "gneiting.matern", "pure.nugget"),
       kappa = NULL, simul.number = NULL, max.dist = "all",
       minimisation.function = "nlm", lower = 0,
       fix.nugget = FALSE, nugget = 0, messages.screen = TRUE)
}

%- maybe also `usage' for other objects documented here.
\arguments{
  \item{vario}{an object with an output of the function
    \code{\link{variog}}. This is a list with information about an
    empirical variogram.}
  \item{ini}{a vector with initial values to be passed to the
    minimization function. If \code{fix.nugget = TRUE} a 2 elements
    vector must be passed with initial values for the sill and range
    parameters, respectively. Otherwise a 3 elements vector should be
    passed with initial values for the nugget, sill and range
    parameters, respectively.}
  \item{cov.model}{a string with the name of the correlation
    function. See function call for the options.}
  \item{kappa}{(fixed) value of the smoothness parameter required by
    some of the correlation functions.}
  \item{simul.number}{number of simulation. To be used when the object passed to the
    argument \code{vario} has empirical variograms for more than one
    data-set (or simulation), indicating which one will be used.}
  \item{max.dist}{maximum distance considered when fitting the
    variogram. Defaults to the maximum distance found in the object passed to the
    argument \code{vario}.}
  \item{minimisation.function}{minimization function used to estimate
    the parameters. Currently only \code{\link{nlm}} is implemented.}
  \item{lower}{lower limits for the parameters. Defaults to zero.}
  \item{fix.nugget}{A flag indication whether or not the nugget parameter
    must be included in the estimation. If \code{fix.nugget = T} the
    argument \code{ini} must be a vector of length 2 otherwise, 3.}
  \item{nugget}{Value of the nugget parameter when \code{fix.nugget =
      TRUE}. Defaults to zero.}
  \item{messages.screen}{a flag \code{TRUE} or \code{FALSE} indicating
    whether or not messages are printed on the screen (or output device)
    while the function is running.}
  \item{\dots}{further parameters to be passed to the minimization
    function. Typically \code{control} type arguments which controls the
    behavior of the minimization algorithm. See documentation of
    \code{\link{nlm}} for further details.}
}

%\details{
%
%}

\value{
  A list with the following components:
  \item{nugget}{value of the nugget parameter, estimated if
    \code{fix.nugget=FALSE} of fixed if \code{fix.nugget=TRUE}.}
  \item{cov.pars}{a vector with estimated values of the covariance
    parameters sill and range, respectively.}
  \item{cov.model}{a string with the name of the correlation function.}
  \item{kappa}{(fixed) value of the smoothness parameter (for some of
    the correlation functions only).}
  \item{value}{minimized value of the loss function.}
  \item{max.dist}{maximum distance considered in the variogram fitting.}
  \item{minimisation.function}{minimization function used.}
  \item{message}{status messages returned by the function.}
  \item{method}{a string \code{"OLS"} indication the parameter estimation method used.}
  \item{call}{the function call.}
}

\references{
  Further information about \code{geoR/geoS} can be found at:\cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
}

\author{
  Paulo Justiniano Ribeiro Jr. \email{paulojus@est.ufpr.br} \cr
  Peter J. Diggle \email{p.diggle@lancaster.ac.uk}.
}

%\note{ ~~further notes~~ }

\seealso{\code{\link{wlsfit}}, \code{\link{likfit}},
  \code{\link{lines.variomodel}}, \code{\link{nlm}}.}

\examples{
data(s100)  # only when using R (not necessary with S-PLUS) 
vario100 <- variog(s100, max.dist=1)
ols <- olsfit(vario100, ini=c(.5, .5), fix.nug=T)
summary(ols)
plot(vario100)
lines(ols)

}

\keyword{spatial}%-- one or more ...
